
import { Logger } from './logger';
import { DiagramBuilder } from "./builder";

declare var require:any;
declare var process:any;

var argv = require('yargs').argv;
var glob = require("glob");

Logger.log('Angular 2 services injection tree builder is running');

if(!argv.files)
{
  Logger.error('Target files must be specified with --files=<pattern>');
  Logger.log('Output service list into JSON file can be done with --outputservicelistjsonfile=<path>');
  Logger.log('Output service tree into text file can be done with --outputservicetreetextfile=<path>');
  Logger.log('Output logs into text file can be done with --outputlogstextfile=<path>');
  process.exit();
}

Logger.log('Reading files from pattern: ' + JSON.stringify(argv.files));

glob(argv.files, {}, (error, files) =>
{
  if(error)
  {
    Logger.error('Error during file read: ' + error);
  }
  else if(!files || !files.length)
  {
    Logger.error('No file found.');
  }
  else
  {
    const builder = new DiagramBuilder(files);
    builder.build();
    builder.printServiceTree();

    if(argv.outputservicelistjsonfile)
    {
      builder.writeServiceListToFile(argv.outputservicelistjsonfile);
    }

    if(argv.outputservicetreetextfile)
    {
      builder.writeServiceTreeToFile(argv.outputservicetreetextfile);
    }

    if(argv.outputlogstextfile)
    {
      builder.writeLogsToFile(argv.outputlogstextfile);
    }
  }
});
